/*
 * Copyright 2020 - All rights reserved.
 * Rodrigo Tapia-McClung
 *
 * November 2020
 */

/* global mapboxgl, turf */

let polygon = {
    "type": "Feature",
    "properties": {},
    "geometry": {
        "type": "Polygon",
        "coordinates": [
            [
                [
                    -99.14920806884764,
                    19.41608763433028
                ],
                [
                    -99.1123867034912,
                    19.41608763433028
                ],
                [
                    -99.1123867034912,
                    19.43818532931131
                ],
                [
                    -99.14920806884764,
                    19.43818532931131
                ],
                [
                    -99.14920806884764,
                    19.41608763433028
                ]
            ]
        ]
    }
}

// define MVT layer for given table and some attributes
const mapboxLayer = (table) => {
    const baseUrl = new URL(`/data`, window.location.href).href;
    let pbfLayer = {
        id: table,
        source: {
            type: "vector",
            tiles: [`${baseUrl}/${table}/mvt/{z}/{x}/{y}?geom_column=denue_geom_4326&columns=denue_nombre, sector, sector_nombre`],
            maxzoom: 19,
            minzoom: 6
        },
        "source-layer": table,
        type: "circle",
        "paint": {
            //"circle-opacity": 0.5,
            "circle-radius": 3.5,
            "circle-color": [
                "interpolate",
                ["linear"],
                ["get", "sector"],
                10, "rgb(49,54,149)",
                50, "rgb(255,255,191)",
                100, "rgb(158,1,66)"
            ],
            'circle-opacity': ['case', ['within', polygon], 0.5, 0],
        }
    }
    return pbfLayer;
}

let map = new mapboxgl.Map({
    container: 'mexmap',
    accessToken: "pk.eyJ1IjoiZGV2ZWxvcGdlbyIsImEiOiJja2dwcXFic20wYnJnMzBrbG11d3dwYTkyIn0.4WwFOH6C7hDQXV9obU6mAw",
    style: 'mapbox://styles/mapbox/dark-v10',
    center: [-100.94, 21.15],
    zoom: 7
});

map.addControl(new mapboxgl.NavigationControl());

let tiles = mapboxLayer("dim_denue2019");

map.on("style.load", () => {
    map.addLayer(tiles);
});

map.on('click', e => {
    if (turf.booleanWithin(turf.point([e.lngLat.lng, e.lngLat.lat]), polygon)) {
        var features = map.queryRenderedFeatures(e.point,
            { layers: ['dim_denue2019'] }
        );

        if (features.length != 0) {
            new mapboxgl.Popup()
                .setLngLat(e.lngLat)
                .setHTML(features[0].properties['denue_nombre'])
                .addTo(map);
        }
    }
});

// Change the cursor to a pointer when the mouse is over the denue layer.
map.on('mouseenter', 'dim_denue2019', e => {
    if (turf.booleanWithin(turf.point([e.lngLat.lng, e.lngLat.lat]), polygon)) {
        map.getCanvas().style.cursor = 'pointer';
    }
});

// Change it back to a pointer when it leaves.
map.on('mouseleave', 'dim_denue2019', () => {
    map.getCanvas().style.cursor = '';
});